use chrono::{Local, Timelike};
use clap::Parser;
use std::{error::Error, path::PathBuf};
use sunrise::Sunrise;

mod sunrise;

#[derive(Parser)]
#[command(version, about, long_about = None)]
struct Cli {
    /// Sunrise file
    file: PathBuf,
}

fn main() -> Result<(), Box<dyn Error>> {
    let cli = Cli::parse();

    let sunrise = Sunrise::load_from_file(&cli.file)?;

    let now = Local::now();
    let sec = now.hour() * 3600 + now.minute() * 60 + now.second();

    match sunrise.closest_passed_time(sec) {
        Some(timetable) => match cli.file.canonicalize()?.parent() {
            Some(sunrise_absolute_base) => {
                let image = timetable.get_absolute_image_path(&sunrise_absolute_base);
                println!("{}", image.to_str().unwrap());
            }
            None => {
                println!("Failed");
            }
        },

        None => {
            println!("Failed");
        }
    }

    Ok(())
}
